@@ -1,6 +1,6 @@
 ;;; helm-utils.el --- Utilities Functions for helm. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2012 ~ 2017 Thierry Volpiatto <thierry.volpiatto@gmail.com>
+;; Copyright (C) 2012 ~ 2018 Thierry Volpiatto <thierry.volpiatto@gmail.com>
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 (declare-function helm-find-files-1 "helm-files.el" (fname &optional preselect))
 (declare-function popup-tip "ext:popup")
 (defvar winner-boring-buffers)
+(defvar helm-show-completion-overlay)
 
 
 (defgroup helm-utils nil
@@ -409,7 +410,7 @@ Default is `helm-current-buffer'."
   (let ((fn (cond ((eq major-mode 'org-mode) #'org-reveal)
                   ((and (boundp 'outline-minor-mode)
                         outline-minor-mode)
-                   #'outline-show-subtree))))
+                   (lambda () (outline-flag-subtree nil))))))
     ;; outline may fail in some conditions e.g. with markdown enabled
     ;; (issue #1919).
     (condition-case nil
@@ -544,6 +545,12 @@ from its directory."
             (expand-file-name (or (buffer-file-name) default-directory))))
          ;; Url.
          ((and (stringp sel) helm--url-regexp (string-match helm--url-regexp sel)) sel)
+         ;; Exit brutally from a `with-helm-show-completion'
+         ((and helm-show-completion-overlay
+               (overlayp helm-show-completion-overlay))
+          (delete-overlay helm-show-completion-overlay)
+          (remove-hook 'helm-move-selection-after-hook 'helm-show-completion)
+          (expand-file-name default-preselection))
          ;; Default.
          (t (expand-file-name default-preselection)))))))
 (put 'helm-quit-and-find-file 'helm-only t)
